indexing

	description: "Class that covers current process related routines."
	usage: "Just inherit from this class."

	author: "Berend de Boer"
	date: "$Date: 2003/01/09 $"
	revision: "$Revision: #3 $"

class

	STDC_CURRENT_PROCESS


inherit

	STDC_PROCESS

	CAPI_STDLIB

	CAPI_LOCALE

	CAPI_TIME


feature -- my stdandard input/output/error

	stdin: STDC_TEXT_FILE is
		once
			create Result.attach_to_stream (stream_stdin, "r")
		end

	stdout: STDC_TEXT_FILE is
		once
			create Result.attach_to_stream (stream_stdout, "w")
		end

	stderr: STDC_TEXT_FILE is
		once
			create Result.attach_to_stream (stream_stderr, "w")
		end


feature {NONE} -- ways to exit a program

	abort is
			-- Causes abnormal process termination
			-- On many systems, dumps core
		do
			posix_abort
		ensure
			we_should_never_come_here: False
		end


	exit (a_status: INTEGER) is
			-- terminate this process with exit code `a_status'
		do
			posix_exit (a_status)
		end

	exit_with_failure is
		do
			exit (EXIT_FAILURE)
		end

	exit_with_success is
		do
			exit (EXIT_SUCCESS)
		end


feature {NONE} -- various

	clock: INTEGER is
			-- return approximation of processor time used by the
			-- program, or -1 if unknown
		do
			Result := posix_clock
		end


feature {NONE} -- random numbers

	random: INTEGER is
			-- returns a pseudo-random integer
		do
			Result := posix_rand
		end

	rand: INTEGER is
		obsolete "use random instead."
		do
			Result := random
		end

	set_random_seed (seed: INTEGER) is
		do
			posix_srand (seed)
		end


feature {NONE} -- global locale

	locale: STRING is
			-- return current locale
		do
			Result := sh.pointer_to_string (posix_setlocale (LC_ALL, default_pointer))
		end

	numeric_format: STDC_LOCALE_NUMERIC is
			-- various information for formatting numbers and monetary
			-- quantities
		once
			create Result
		end

	set_locale (category: INTEGER; new_locale: STRING) is
			-- set given locale to `new_locale'
		local
			p: POINTER
		do
			p := posix_setlocale (category, sh.string_to_pointer (new_locale))
			if p = default_pointer then
				raise_posix_error
			end
		end

	set_c_locale is
			-- set locale to the Standard C locale (the default)
		do
			set_locale (LC_ALL, "C")
		end

	set_native_decimal_point is
			-- set the decimal point character
		do
			set_locale (LC_NUMERIC, "")
		end

	set_native_locale is
			-- set entire locale to the native's setting
		do
			set_locale (LC_ALL, "")
		end

	set_native_time is
			-- set time display to the native's setting
		do
			set_locale (LC_TIME, "")
		end


end
